import type { BreakpointsTokenGroup, BreakpointsTokenName, breakpoints as metaBreakpointsTokenGroup } from './token-groups/breakpoints';
import type { Exact, MetadataGroup, TokenGroup, Tokens } from './types';
export declare function getUnit(value?: string): string | null;
export declare function toPx(value?: string): string | undefined;
export declare function toEm(value?: string, fontSize?: number): string | undefined;
export declare function toRem(value?: string): string | undefined;
export declare function rem(value: string): string;
export declare function tokensToRems<T extends Exact<MetadataGroup, T>>(tokenGroup: T): T;
export declare function createVar(token: string): string;
/**
 * Allowed Foundation keyframes.
 *
 * Result: ['p-keyframes-fade-in', 'p-keyframes-spin', etc...]
 */
export declare function getKeyframeNames(motionTokenGroup: TokenGroup): (string | null)[];
/**
 * Allowed Foundation token custom properties.
 *
 * Result: ['--p-color-bg-app', '--p-color-text', etc...]
 */
export declare function getCustomPropertyNames(tokens: Tokens): string[];
export declare function removeMetadata<T extends Exact<MetadataGroup, T>>(tokenGroup: T): TokenGroup<T>;
export type MetaBreakpointsTokenGroup = typeof metaBreakpointsTokenGroup;
/**
 * Alias direction used for composing Foundation `breakpoints` utilities.
 */
export type BreakpointsAliasDirection = 'up' | 'down' | 'only';
/**
 * A collection of directional media conditions for a given Foundation `breakpoints` alias.
 */
export type BreakpointsAliasDirectionMediaConditions = {
    [AliasDirection in BreakpointsAliasDirection]: string;
};
/**
 * Media conditions for all Foundation `breakpoints` aliases.
 */
export type BreakpointsMediaConditions = {
    [TokenName in BreakpointsTokenName]: BreakpointsAliasDirectionMediaConditions;
};
export declare function getMediaConditions(breakpoints: BreakpointsTokenGroup): BreakpointsMediaConditions;
export declare function isKeyOf<T extends {
    [key: string]: any;
}>(obj: T, key: PropertyKey | undefined): key is keyof T;
//# sourceMappingURL=utilities.d.ts.map